facade_mocks

package
v0.0.0-...-1842cec Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package facade_mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockAuth

type MockAuth struct {
	// contains filtered or unexported fields
}

MockAuth is a mock of Auth interface.

func NewMockAuth

func NewMockAuth(ctrl *gomock.Controller) *MockAuth

NewMockAuth creates a new mock instance.

func (*MockAuth) CreateUserClaims

func (m *MockAuth) CreateUserClaims(user model.User) jwt.Claims

CreateUserClaims mocks base method.

func (*MockAuth) EXPECT

func (m *MockAuth) EXPECT() *MockAuthMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockAuth) GenerateRefreshToken

func (m *MockAuth) GenerateRefreshToken() (string, time.Time, error)

GenerateRefreshToken mocks base method.

func (*MockAuth) GenerateToken

func (m *MockAuth) GenerateToken(claims jwt.Claims) (string, error)

GenerateToken mocks base method.

func (*MockAuth) GetClaimsFromToken

func (m *MockAuth) GetClaimsFromToken(tokenStr string) (auth.Claims, error)

GetClaimsFromToken mocks base method.

type MockAuthMockRecorder

type MockAuthMockRecorder struct {
	// contains filtered or unexported fields
}

MockAuthMockRecorder is the mock recorder for MockAuth.

func (*MockAuthMockRecorder) CreateUserClaims

func (mr *MockAuthMockRecorder) CreateUserClaims(user any) *gomock.Call

CreateUserClaims indicates an expected call of CreateUserClaims.

func (*MockAuthMockRecorder) GenerateRefreshToken

func (mr *MockAuthMockRecorder) GenerateRefreshToken() *gomock.Call

GenerateRefreshToken indicates an expected call of GenerateRefreshToken.

func (*MockAuthMockRecorder) GenerateToken

func (mr *MockAuthMockRecorder) GenerateToken(claims any) *gomock.Call

GenerateToken indicates an expected call of GenerateToken.

func (*MockAuthMockRecorder) GetClaimsFromToken

func (mr *MockAuthMockRecorder) GetClaimsFromToken(tokenStr any) *gomock.Call

GetClaimsFromToken indicates an expected call of GetClaimsFromToken.

type MockEmailSender

type MockEmailSender struct {
	// contains filtered or unexported fields
}

MockEmailSender is a mock of EmailSender interface.

func NewMockEmailSender

func NewMockEmailSender(ctrl *gomock.Controller) *MockEmailSender

NewMockEmailSender creates a new mock instance.

func (*MockEmailSender) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockEmailSender) SendEmailVerification

func (m *MockEmailSender) SendEmailVerification(ctx context.Context, req resendapi.SendEmailVerificationRequest) (string, error)

SendEmailVerification mocks base method.

type MockEmailSenderMockRecorder

type MockEmailSenderMockRecorder struct {
	// contains filtered or unexported fields
}

MockEmailSenderMockRecorder is the mock recorder for MockEmailSender.

func (*MockEmailSenderMockRecorder) SendEmailVerification

func (mr *MockEmailSenderMockRecorder) SendEmailVerification(ctx, req any) *gomock.Call

SendEmailVerification indicates an expected call of SendEmailVerification.

type MockInfoAPIClient

type MockInfoAPIClient struct {
	// contains filtered or unexported fields
}

MockInfoAPIClient is a mock of InfoAPIClient interface.

func NewMockInfoAPIClient

func NewMockInfoAPIClient(ctrl *gomock.Controller) *MockInfoAPIClient

NewMockInfoAPIClient creates a new mock instance.

func (*MockInfoAPIClient) CompanyExists

func (m *MockInfoAPIClient) CompanyExists(ctx context.Context, companyName string) (bool, error)

CompanyExists mocks base method.

func (*MockInfoAPIClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

type MockInfoAPIClientMockRecorder

type MockInfoAPIClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockInfoAPIClientMockRecorder is the mock recorder for MockInfoAPIClient.

func (*MockInfoAPIClientMockRecorder) CompanyExists

func (mr *MockInfoAPIClientMockRecorder) CompanyExists(ctx, companyName any) *gomock.Call

CompanyExists indicates an expected call of CompanyExists.

type MockUserRepo

type MockUserRepo struct {
	// contains filtered or unexported fields
}

MockUserRepo is a mock of UserRepo interface.

func NewMockUserRepo

func NewMockUserRepo(ctrl *gomock.Controller) *MockUserRepo

NewMockUserRepo creates a new mock instance.

func (*MockUserRepo) CheckUserExists

func (m *MockUserRepo) CheckUserExists(ctx context.Context, name string, role model.Role) (bool, error)

CheckUserExists mocks base method.

func (*MockUserRepo) CreateEmailUnsubscribe

func (m *MockUserRepo) CreateEmailUnsubscribe(ctx context.Context, unsubscribe database.EmailUnsubscribe) error

CreateEmailUnsubscribe mocks base method.

func (*MockUserRepo) CreateEmailVerification

func (m *MockUserRepo) CreateEmailVerification(ctx context.Context, verification database.EmailVerification) error

CreateEmailVerification mocks base method.

func (*MockUserRepo) CreateRefreshToken

func (m *MockUserRepo) CreateRefreshToken(ctx context.Context, refreshToken database.RefreshToken) error

CreateRefreshToken mocks base method.

func (*MockUserRepo) CreateUser

func (m *MockUserRepo) CreateUser(ctx context.Context, user database.User) error

CreateUser mocks base method.

func (m *MockUserRepo) CreateUserOAuthLink(ctx context.Context, link database.UserOAuthLink) error

CreateUserOAuthLink mocks base method.

func (*MockUserRepo) DeleteRefreshToken

func (m *MockUserRepo) DeleteRefreshToken(ctx context.Context, token string) error

DeleteRefreshToken mocks base method.

func (*MockUserRepo) DeleteRefreshTokensByUserID

func (m *MockUserRepo) DeleteRefreshTokensByUserID(ctx context.Context, userID string) error

DeleteRefreshTokensByUserID mocks base method.

func (*MockUserRepo) DeleteUser

func (m *MockUserRepo) DeleteUser(ctx context.Context, userID string) error

DeleteUser mocks base method.

func (*MockUserRepo) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockUserRepo) GetEmailVerificationByUserID

func (m *MockUserRepo) GetEmailVerificationByUserID(ctx context.Context, userID string) (database.EmailVerification, error)

GetEmailVerificationByUserID mocks base method.

func (*MockUserRepo) GetRefreshTokenByHash

func (m *MockUserRepo) GetRefreshTokenByHash(ctx context.Context, tokenHash string) (database.RefreshToken, error)

GetRefreshTokenByHash mocks base method.

func (*MockUserRepo) GetUserByEmail

func (m *MockUserRepo) GetUserByEmail(ctx context.Context, email string) (database.User, error)

GetUserByEmail mocks base method.

func (*MockUserRepo) GetUserByID

func (m *MockUserRepo) GetUserByID(ctx context.Context, userID string) (database.User, error)

GetUserByID mocks base method.

func (m *MockUserRepo) GetUserByOAuthLink(ctx context.Context, provider, oauthID string) (database.User, error)

GetUserByOAuthLink mocks base method.

func (*MockUserRepo) GetUserByUsername

func (m *MockUserRepo) GetUserByUsername(ctx context.Context, username string) (database.User, error)

GetUserByUsername mocks base method.

func (m *MockUserRepo) HasOAuthLink(ctx context.Context, userID string) (bool, error)

HasOAuthLink mocks base method.

func (*MockUserRepo) IsEmailUnsubscribed

func (m *MockUserRepo) IsEmailUnsubscribed(ctx context.Context, email string) (bool, error)

IsEmailUnsubscribed mocks base method.

func (*MockUserRepo) RunWithTx

func (m *MockUserRepo) RunWithTx(ctx context.Context, f func(context.Context) error) error

RunWithTx mocks base method.

func (*MockUserRepo) SetEmailVerificationMessageID

func (m *MockUserRepo) SetEmailVerificationMessageID(ctx context.Context, verificationID, messageID string) error

SetEmailVerificationMessageID mocks base method.

func (*MockUserRepo) SetEmailVerificationUsed

func (m *MockUserRepo) SetEmailVerificationUsed(ctx context.Context, id string, verified bool) error

SetEmailVerificationUsed mocks base method.

func (*MockUserRepo) SetUnsubscribeToken

func (m *MockUserRepo) SetUnsubscribeToken(ctx context.Context, id, token string) error

SetUnsubscribeToken mocks base method.

func (*MockUserRepo) SetUserEmailVerified

func (m *MockUserRepo) SetUserEmailVerified(ctx context.Context, userID string) error

SetUserEmailVerified mocks base method.

func (*MockUserRepo) UpdateUser

func (m *MockUserRepo) UpdateUser(ctx context.Context, user database.User) error

UpdateUser mocks base method.

type MockUserRepoMockRecorder

type MockUserRepoMockRecorder struct {
	// contains filtered or unexported fields
}

MockUserRepoMockRecorder is the mock recorder for MockUserRepo.

func (*MockUserRepoMockRecorder) CheckUserExists

func (mr *MockUserRepoMockRecorder) CheckUserExists(ctx, name, role any) *gomock.Call

CheckUserExists indicates an expected call of CheckUserExists.

func (*MockUserRepoMockRecorder) CreateEmailUnsubscribe

func (mr *MockUserRepoMockRecorder) CreateEmailUnsubscribe(ctx, unsubscribe any) *gomock.Call

CreateEmailUnsubscribe indicates an expected call of CreateEmailUnsubscribe.

func (*MockUserRepoMockRecorder) CreateEmailVerification

func (mr *MockUserRepoMockRecorder) CreateEmailVerification(ctx, verification any) *gomock.Call

CreateEmailVerification indicates an expected call of CreateEmailVerification.

func (*MockUserRepoMockRecorder) CreateRefreshToken

func (mr *MockUserRepoMockRecorder) CreateRefreshToken(ctx, refreshToken any) *gomock.Call

CreateRefreshToken indicates an expected call of CreateRefreshToken.

func (*MockUserRepoMockRecorder) CreateUser

func (mr *MockUserRepoMockRecorder) CreateUser(ctx, user any) *gomock.Call

CreateUser indicates an expected call of CreateUser.

func (mr *MockUserRepoMockRecorder) CreateUserOAuthLink(ctx, link any) *gomock.Call

CreateUserOAuthLink indicates an expected call of CreateUserOAuthLink.

func (*MockUserRepoMockRecorder) DeleteRefreshToken

func (mr *MockUserRepoMockRecorder) DeleteRefreshToken(ctx, token any) *gomock.Call

DeleteRefreshToken indicates an expected call of DeleteRefreshToken.

func (*MockUserRepoMockRecorder) DeleteRefreshTokensByUserID

func (mr *MockUserRepoMockRecorder) DeleteRefreshTokensByUserID(ctx, userID any) *gomock.Call

DeleteRefreshTokensByUserID indicates an expected call of DeleteRefreshTokensByUserID.

func (*MockUserRepoMockRecorder) DeleteUser

func (mr *MockUserRepoMockRecorder) DeleteUser(ctx, userID any) *gomock.Call

DeleteUser indicates an expected call of DeleteUser.

func (*MockUserRepoMockRecorder) GetEmailVerificationByUserID

func (mr *MockUserRepoMockRecorder) GetEmailVerificationByUserID(ctx, userID any) *gomock.Call

GetEmailVerificationByUserID indicates an expected call of GetEmailVerificationByUserID.

func (*MockUserRepoMockRecorder) GetRefreshTokenByHash

func (mr *MockUserRepoMockRecorder) GetRefreshTokenByHash(ctx, tokenHash any) *gomock.Call

GetRefreshTokenByHash indicates an expected call of GetRefreshTokenByHash.

func (*MockUserRepoMockRecorder) GetUserByEmail

func (mr *MockUserRepoMockRecorder) GetUserByEmail(ctx, email any) *gomock.Call

GetUserByEmail indicates an expected call of GetUserByEmail.

func (*MockUserRepoMockRecorder) GetUserByID

func (mr *MockUserRepoMockRecorder) GetUserByID(ctx, userID any) *gomock.Call

GetUserByID indicates an expected call of GetUserByID.

func (mr *MockUserRepoMockRecorder) GetUserByOAuthLink(ctx, provider, oauthID any) *gomock.Call

GetUserByOAuthLink indicates an expected call of GetUserByOAuthLink.

func (*MockUserRepoMockRecorder) GetUserByUsername

func (mr *MockUserRepoMockRecorder) GetUserByUsername(ctx, username any) *gomock.Call

GetUserByUsername indicates an expected call of GetUserByUsername.

func (mr *MockUserRepoMockRecorder) HasOAuthLink(ctx, userID any) *gomock.Call

HasOAuthLink indicates an expected call of HasOAuthLink.

func (*MockUserRepoMockRecorder) IsEmailUnsubscribed

func (mr *MockUserRepoMockRecorder) IsEmailUnsubscribed(ctx, email any) *gomock.Call

IsEmailUnsubscribed indicates an expected call of IsEmailUnsubscribed.

func (*MockUserRepoMockRecorder) RunWithTx

func (mr *MockUserRepoMockRecorder) RunWithTx(ctx, f any) *gomock.Call

RunWithTx indicates an expected call of RunWithTx.

func (*MockUserRepoMockRecorder) SetEmailVerificationMessageID

func (mr *MockUserRepoMockRecorder) SetEmailVerificationMessageID(ctx, verificationID, messageID any) *gomock.Call

SetEmailVerificationMessageID indicates an expected call of SetEmailVerificationMessageID.

func (*MockUserRepoMockRecorder) SetEmailVerificationUsed

func (mr *MockUserRepoMockRecorder) SetEmailVerificationUsed(ctx, id, verified any) *gomock.Call

SetEmailVerificationUsed indicates an expected call of SetEmailVerificationUsed.

func (*MockUserRepoMockRecorder) SetUnsubscribeToken

func (mr *MockUserRepoMockRecorder) SetUnsubscribeToken(ctx, id, token any) *gomock.Call

SetUnsubscribeToken indicates an expected call of SetUnsubscribeToken.

func (*MockUserRepoMockRecorder) SetUserEmailVerified

func (mr *MockUserRepoMockRecorder) SetUserEmailVerified(ctx, userID any) *gomock.Call

SetUserEmailVerified indicates an expected call of SetUserEmailVerified.

func (*MockUserRepoMockRecorder) UpdateUser

func (mr *MockUserRepoMockRecorder) UpdateUser(ctx, user any) *gomock.Call

UpdateUser indicates an expected call of UpdateUser.

Jump to