database_mocks

package
v0.0.0-...-1842cec Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package database_mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockExecutor

type MockExecutor struct {
	// contains filtered or unexported fields
}

MockExecutor is a mock of Executor interface.

func NewMockExecutor

func NewMockExecutor(ctrl *gomock.Controller) *MockExecutor

NewMockExecutor creates a new mock instance.

func (*MockExecutor) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockExecutor) ExecContext

func (m *MockExecutor) ExecContext(ctx context.Context, query string, args ...any) (sql.Result, error)

ExecContext mocks base method.

func (*MockExecutor) GetContext

func (m *MockExecutor) GetContext(ctx context.Context, dest any, query string, args ...any) error

GetContext mocks base method.

type MockExecutorMockRecorder

type MockExecutorMockRecorder struct {
	// contains filtered or unexported fields
}

MockExecutorMockRecorder is the mock recorder for MockExecutor.

func (*MockExecutorMockRecorder) ExecContext

func (mr *MockExecutorMockRecorder) ExecContext(ctx, query any, args ...any) *gomock.Call

ExecContext indicates an expected call of ExecContext.

func (*MockExecutorMockRecorder) GetContext

func (mr *MockExecutorMockRecorder) GetContext(ctx, dest, query any, args ...any) *gomock.Call

GetContext indicates an expected call of GetContext.

type MockQuerier

type MockQuerier struct {
	// contains filtered or unexported fields
}

MockQuerier is a mock of Querier interface.

func NewMockQuerier

func NewMockQuerier(ctrl *gomock.Controller) *MockQuerier

NewMockQuerier creates a new mock instance.

func (*MockQuerier) EXPECT

func (m *MockQuerier) EXPECT() *MockQuerierMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockQuerier) Exec

func (m *MockQuerier) Exec(ctx context.Context, query string, args ...any) (sql.Result, error)

Exec mocks base method.

func (*MockQuerier) Get

func (m *MockQuerier) Get(ctx context.Context, dest any, query string, args ...any) error

Get mocks base method.

type MockQuerierMockRecorder

type MockQuerierMockRecorder struct {
	// contains filtered or unexported fields
}

MockQuerierMockRecorder is the mock recorder for MockQuerier.

func (*MockQuerierMockRecorder) Exec

func (mr *MockQuerierMockRecorder) Exec(ctx, query any, args ...any) *gomock.Call

Exec indicates an expected call of Exec.

func (*MockQuerierMockRecorder) Get

func (mr *MockQuerierMockRecorder) Get(ctx, dest, query any, args ...any) *gomock.Call

Get indicates an expected call of Get.

Jump to