Documentation
¶
Index ¶
Constants ¶
const ( // VerificationCodeTTL is the time a verification code is valid for VerificationCodeTTL = 24 * time.Hour // UnsubscribeTokenTTL is the time an unsubscribe token is valid for UnsubscribeTokenTTL = 7 * 24 * time.Hour // ResendVerificationCodeCooldown is the cooldown period between verification code resends ResendVerificationCodeCooldown = 120 * time.Second )
const ( // GoogleAuthTokenProvider is google auth token provider GoogleAuthTokenProvider = "google" // GitHubAuthTokenProvider is github auth token provider GitHubAuthTokenProvider = "github" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type UpdateProfileParams ¶
UpdateProfileParams contains parameters for updating user profile
Click to show internal directories.
Click to hide internal directories.